import React from "react"
import { twMerge } from "tailwind-merge"

import { InformationCircleIcon } from "@heroicons/react/outline"

interface Props {
    children?: React.ReactNode
    text?: string
    className?: string
}

const Tooltip = (props: Props) => {
    const { children, text = "", className = "" } = props
    if (text === "") return null

    return (
        <span className={twMerge("tooltip", className)}>
            <div className="group ml-2 inline-block">
                <InformationCircleIcon className="text-info h-4 w-4 cursor-pointer" />
                <div className="invisible absolute bottom-full left-1/2 z-10 mt-2 w-56 -translate-x-1/2 transform rounded-lg bg-white p-5 py-2 text-xs font-normal opacity-0 shadow transition-all duration-300 group-hover:visible group-hover:opacity-100">
                    <InformationCircleIcon className="text-info m-2 mx-auto h-6 w-6 text-center" />
                    {text}
                </div>
            </div>
        </span>
    )
}

export default Tooltip
